<!--
SPDX-FileCopyrightText: 2023-2024 Helmholtz-Zentrum hereon GmbH, Deutsches Klimarechenzentrum GmbH

SPDX-License-Identifier: CC-BY-4.0
-->

# Template for a freva plugin

[![REUSE status](https://api.reuse.software/badge/gitlab.dkrz.de/ch1187/plugins4freva/freva-plugin-template)](https://api.reuse.software/info/gitlab.dkrz.de/ch1187/plugins4freva/freva-plugin-template)
[![License](https://img.shields.io/gitlab/license/ch1187/plugins4freva/freva-plugin-template?gitlab_url=https%3A%2F%2Fgitlab.dkrz.de)](https://gitlab.dkrz.de/ch1187/plugins4freva/freva-plugin-template#license-information)

This repository serves as the starting point for plugin development, providing a basic structure for a Freva Plugin. It enables plugin developers to implement their scientific ideas within a well-structured framework, equipped with state-of-the-art tools.

<div align="center">
  <img src="_static/freva-plugin-template-logo.png" alt="Logo" width="60%"/>
</div>

## Let's create your first Freva plugin

To create your first Freva plugin, you need to first install this package:

```bash
python -m venv venv
source venv/bin/activate
pip install git+https://gitlab.dkrz.de/ch1187/plugins4freva/freva-plugin-template.git
```

To ensure you installed the package, try to see if `freva-plugin-template` works or not, if it works you have to see something like this:

```sh
❯ freva-plugin-template
usage: freva-plugin-template [-h] {create,update} ...

Freva Plugin Template CLI

positional arguments:
  {create,update}  Sub-command help
    create         Create a new Freva plugin template
    update         Update an existing Freva plugin template

options:
  -h, --help       show this help message and exit
```

Now you can generate a new Freva plugin with the following command:


```bash
freva-plugin-template create
```

> **NOTE**
>
> This process will prompt you for some input, including a `plugin_slug`,
> which will be used to create the skeleton of your new Freva plugin. For details
> on individual configuration parameters and possible environment variables,
> refer to the [parameters.rst](parameters.rst) file.


The newly created folder will be set up as a git repository, with the new
files automatically staged. All necessary formatters will be run to ensure
high code quality from the start.

Finally, you will receive 5 steps instructions on how to complete the initial setup.

#### Activating CI/CD Pipeline and Runner

After pushing the newly generated plugin to GitLab, you need to activate
the CI/CD pipeline. Follow these steps:

1. Activate CI/CD Pipeline:
   - Navigate to `Settings` -> `General` -> `Visibility, project features, permissions`
    and activate the CI/CD pipeline.

2. Activate Shared Runner:
   - If you are using the GitLab instance provided by DKRZ, activate the shared runner.
   This can be done by navigating to `Settings` -> `CI/CD` -> `Runners` and then
   enabling the `Instance runners`.
   - If you are using a different GitLab instance, go to `Settings` ->
   `CI/CD` -> `Runners` and activate a shared runner contain with the `docker`
   tag, if available. If no such runner is available, you will need to
   [configure your runner locally](https://docs.gitlab.com/runner/configuration/).

> **Note**
>
> You can also clone this repository via `git clone`, but we recommend to
> use the URL. Otherwise `cruft` will store the path to the local folder
> in the `.cruft.json` configuration file.


## TL;DR - Too Long; Didn't Read!

Instead of reading the long story above, you can simply watch the following video which in simple demonestrate how to create your first plugin:


![Installation and Usage Video](_static/installation_usage_freva_template.mp4)


## Support and Contact Information
If you have any questions or troubles with these tools, please contact
the maintainers of this template rather sooner than later. You can
[open an issue in this repository](https://gitlab.dkrz.de/ch1187/plugins4freva/freva-plugin-template/-/issues/new) or contact us at [freva@dkrz.de](mailtto:freva@dkrz.de).

## License Information

If not specified otherwise in the header of the file or a `.license` file
next to it, the template files in this repository (i.e. everything in the
`{{cookiecutter.plugin_slug}}` folder) are licensed under Public Domain
(`CC0-1.0`). See `.reuse/dep5` for further information.

For other files, please refer to the header of the corresponding file.

All license files are located in the [LICENSES](LICENSES) folder at the root
of the repository.


## Extending this template

This template is a very basic template for an arbitrary Freva Plugin.
Depending on the libraries and frameworks that you use, you might want
to use this repository as a starting point to create your own template.
If you want to do so, you should [create a fork of this repository](https://gitlab.dkrz.de/ch1187/plugins4freva/freva-plugin-template/-/forks/new)
and implement the changes or additions in your fork. By doing so, you
can always merge changes from this repository into your fork and stay
up-to-date with the code quality tools that we use here.

If you want to directly make improvements to this template, please
[do so in a merge request at the source code repository](https://gitlab.dkrz.de/ch1187/plugins4freva/freva-plugin-template/-/merge_requests/new)
or [create an issue](https://gitlab.dkrz.de/ch1187/plugins4freva/freva-plugin-template/-/issues/new).

If you want to contribute on this project, you can simply submit an MR to this repository.

### Running tests

This repo is using [`bats`](https://bats-core.readthedocs.io/en/stable/) for
automated tests. `bats` is contained as git submodules in the source code
repository. So if you clone this repo via

```bash
git clone --recursive https://gitlab.dkrz.de/ch1187/plugins4freva/freva-plugin-template.git
```

or run a

```bash
git submodule update --init
```


once you cloned it, install the prerequsites via

```
pip install -e .
```

and then you can run the test suite via

```bash
./test/bats/bin/bats test/
```

Note that this command needs to be enquired from a bash shell (e.g. `Git Bash`
on windows).

See also the setup in the [gitlab CI config file](.gitlab-ci.yml) for a working
setup.

## Important note:

This repository is a fork of [python-package-template](https://codebase.helmholtz.cloud/hcdc/software-templates/python-package-template), originally hosted on [Helmholtz Codebase](https://codebase.helmholtz.cloud). Due to the lack of direct cross-host forking capabilities in GitLab, we manually forked this repository. This fork is specifically intended to modify the existing template into a cookiecutter template suitable for freva plugins, enhancing its usability and applicability within our projects.
