# {{ cookiecutter.plugin_title }}

[![CI](https://{{ cookiecutter.gitlab_host }}/{{ cookiecutter.gitlab_username }}/{{ cookiecutter.plugin_slug }}/badges/main/pipeline.svg)](https://{{ cookiecutter.gitlab_host }}/{{ cookiecutter.gitlab_username }}/{{ cookiecutter.plugin_slug }}/-/pipelines?page=1&scope=all&ref=main)
[![Code coverage](https://{{ cookiecutter.gitlab_host }}/{{ cookiecutter.gitlab_username }}/{{ cookiecutter.plugin_slug }}/badges/main/coverage.svg)](https://{{ cookiecutter.gitlab_host }}/{{ cookiecutter.gitlab_username }}/{{ cookiecutter.plugin_slug }}/-/graphs/main/charts)

{%- if 'documentation_url' in cookiecutter and 'readthedocs' in cookiecutter.documentation_url %}
[![Docs](https://readthedocs.org/projects/{{ cookiecutter.plugin_slug }}/badge/?version=latest)]({{ cookiecutter.documentation_url }})
{%- endif %}
{%- if 'use_reuse' in cookiecutter %}
<!-- TODO: uncomment the following line when the package is registered at https://api.reuse.software -->
<!-- [![REUSE status](https://api.reuse.software/badge/{{ cookiecutter.gitlab_host }}/{{ cookiecutter.gitlab_username }}/{{ cookiecutter.plugin_slug }})](https://api.reuse.software/info/{{ cookiecutter.gitlab_host }}/{{ cookiecutter.gitlab_username }}/{{ cookiecutter.plugin_slug }}) -->
{%- endif %}


{% if cookiecutter.plugin_short_description != cookiecutter.plugin_title %}{{ cookiecutter.plugin_short_description }}{% endif %}


## Connection and Module Loading

To connect to the server and load the necessary modules for the project, use the following commands:

```bash
ssh <user-id>@levante.dkrz.de
module load clint <project-module>
```

> **Note**
>
> To find module of your project, you can use get the list of all
> avaiable modules via `module avail`.


## Integrating {{ cookiecutter.plugin_title }} with the Plugin

To integrate {{ cookiecutter.plugin_title }} into your Freva instance, follow these steps:

1. **Clone the Plugin Repository:**

    Navigate to the appropriate directory and clone the repository using the following commands:

    ```bash
    cd <project-dir>
    git clone https://{{ cookiecutter.gitlab_host }}/{{ cookiecutter.gitlab_username }}/{{ cookiecutter.plugin_slug }}.git
    ```

    > **Note**
    >
    > One easy way to find the `<project-dir>` that you logged in,
    > is using the following lines:

    ```bash
    $ module load clint <project-module>
    $ ipython

    In [1]: from evaluation_system.model.user import User

    In [2]: user = User()

    In [3]: user.getUserBaseDir()
    Out[3]: <project-dir>
    ```

2. **Install Prerequisites:**

    After cloning the repository, install the required packages:

    ```bash
    cd {{ cookiecutter.plugin_slug }}
    make mamba-dep-install
    conda activate plugin_env
    ```

    or simply the following conda command:

    ```bash
    cd {{ cookiecutter.plugin_slug }}
    conda env create --prefix ./plugin_env -f {{cookiecutter.plugin_slug}}-env.yml
    conda activate plugin_env
    pip install .
    ```

    > **Note**
    > In all the steps above, you can use, `conda` instead of `mamba`.
    > For example instead of make `mamba-dep-install` you can use
    > `make conda-dep-install`. But to do the installation of environemt
    > faster, it's highly recommended to use `mamba`

3. **Configure the Freva Instance:**

    Use the following export command to make the plugin available in your Freva instance:

    ```bash
    export EVALUATION_SYSTEM_PLUGINS=<project-dir>/{{cookiecutter.plugin_slug}},{{cookiecutter.plugin_slug}}-wrapper-api
    ```

Now, the plugin is ready to be used in your Freva instance.

## Development and contribution

To use this in a development setup, clone the [source code](clone https://{{ cookiecutter.gitlab_host }}/{{ cookiecutter.gitlab_username }}/{{ cookiecutter.plugin_slug }}.git) from
gitlab, start the development server and make your changes:

```bash
git clone https://{{ cookiecutter.gitlab_host }}/{{ cookiecutter.gitlab_username }}/{{ cookiecutter.plugin_slug }}.git
cd {{ cookiecutter.plugin_slug }}
conda env create --prefix ./plugin_env -f {{cookiecutter.plugin_slug}}-env.yml
conda activate plugin_env
```

More detailed installation instructions my be found in the [docs]({{ cookiecutter.documentation_url }}installation.html).


[source code]: https://{{ cookiecutter.gitlab_host }}/{{ cookiecutter.gitlab_username }}/{{ cookiecutter.plugin_slug }}
{%- if 'documentation_url' in cookiecutter and 'readthedocs' in cookiecutter.documentation_url %}
[docs]: {{ cookiecutter.documentation_url }}installation.html
{% endif %}


For more information on how to contribute to the plugin as well as important details regarding standars and license management chek the [contributing guide][contributing].


## Technical note

This package has been generated from the template
[Freva Plugin Template](https://gitlab.dkrz.de/ch1187/plugins4freva/freva-plugin-template).

See the template repository for instructions on how to update the skeleton for
this package.


## License information
{% if 'copyright_year' in cookiecutter %}
Copyright © {{ cookiecutter.copyright_year }} {{ cookiecutter.copyright_holder }}
{% endif %}
{% if 'use_reuse' in cookiecutter and cookiecutter.use_reuse == "yes" %}

Code files in this repository are licensed under the
{{ cookiecutter.code_license }}, if not stated otherwise
in the file.

{% if 'documentation_license' in cookiecutter %}
Documentation files in this repository are licensed under {{ cookiecutter.documentation_license }}, if not stated otherwise in the file.
{% endif %}

{% if 'supplementary_files_license' in cookiecutter %}
Supplementary and configuration files in this repository are licensed
under {{ cookiecutter.supplementary_files_license }}, if not stated otherwise
in the file.
{% endif %}
Please check the header of the individual files for more detailed
information.

{% else %}
All rights reserved.
{% endif %}

### License management

License management is handled with [``reuse``](https://reuse.readthedocs.io/).
If you have any questions on this, please have a look into the
[contributing guide][contributing] or contact the maintainers of
`{{ cookiecutter.plugin_slug }}`.
{%- if 'documentation_url' in cookiecutter and 'readthedocs' in cookiecutter.documentation_url %}
[contributing]: {{ cookiecutter.documentation_url }}contributing.html
{% endif %}
