# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys
from pathlib import Path

from sphinx.ext import apidoc

sys.path.insert(0, os.path.abspath(".."))

if not os.path.exists("_static"):
    os.makedirs("_static")

# isort: off
sys.path.insert(0, os.path.abspath('../src'))
import {{ cookiecutter.plugin_folder }}

# isort: on


def generate_apidoc(app):
    appdir = Path(app.__file__).parent
    apidoc.main(
        ["-fMEeTo", str(api), str(appdir), str(appdir / "migrations" / "*")]
    )


api = Path("api")

if not api.exists():
    generate_apidoc({{ cookiecutter.plugin_folder }})

# -- Plugin information -----------------------------------------------------

project = "{{ cookiecutter.plugin_slug }}"
{% if 'copyright_year' in cookiecutter and cookiecutter.copyright_year == "yes" %}
copyright = "{{ cookiecutter.copyright_year }} {{ cookiecutter.copyright_holder }}"
{% endif %}
author = "{{ cookiecutter.plugin_authors }}"


linkcheck_ignore = [
    # we do not check link of the {{ cookiecutter.plugin_slug }} as the
    # badges might not yet work everywhere. Once {{ cookiecutter.plugin_slug }}
    # is settled, the following link should be removed
    r'https://.*{{ cookiecutter.plugin_slug }}'
]


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "hereon_nc_sphinxext",
    "sphinx.ext.intersphinx",
    "sphinx_design",
    "sphinx.ext.napoleon",
    "sphinx.ext.todo",
    "autodocsumm",
    "sphinx.ext.autodoc",
    "sphinx.ext.autosummary",
    {% if 'use_markdown_for_documentation' in cookiecutter and cookiecutter.use_markdown_for_documentation == "yes" %}"myst_parser"{%- endif %}
]

{% if 'use_markdown_for_documentation' in cookiecutter and cookiecutter.use_markdown_for_documentation == "yes" %}
myst_enable_extensions = ["fieldlist"]

source_suffix = {
    ".rst": "restructuredtext",
    ".md": "markdown",
}
{% endif %}

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]


autodoc_default_options = {
    "show_inheritance": True,
    "members": True,
    "autosummary": True,
}


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
html_theme = "sphinx_rtd_theme"

html_theme_options = {
    "collapse_navigation": False,
    "includehidden": False,
}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]


intersphinx_mapping = {
    "python": ("https://docs.python.org/3/", None),
    "django": ("https://django.readthedocs.io/en/stable/", None),
}
