"""
A sample script to demonstrate the use of the Freva Plugin

This script is going to get search data and calculate the mean
of the data and save it to the output directory
"""

import ast
import json
import os
import sys
import zipfile

import xarray as xr

# First we need to parse the configuration here to get the values
json_file_path = sys.argv[1]

with open(json_file_path, "r") as json_file:
    config_dict = json.load(json_file)


def sample_function(config_dict):
    files = ast.literal_eval(str(config_dict["files"]))
    path_output: str = str(config_dict["path_output"])
    # Now we can calculate the mean of the data
    ds = xr.open_mfdataset(files[:2]).isel(time=slice(0, 2))
    mean = ds.mean(dim="time")

    # multiple the mean by multiply_by
    mean = mean * int(config_dict["multiply_by"])

    # substract the mean by substraction_from
    mean = mean - float(config_dict["substraction_from"])

    # Save the mean to the output directory
    output_file = os.path.join(path_output, "mean.nc")
    mean.to_netcdf(output_file)

    # Create zip file containing only the mean.nc file
    zip_path = os.path.join(path_output, "00_mean.zip")
    with zipfile.ZipFile(zip_path, "w") as zipf:
        zipf.write(output_file, os.path.basename(output_file))


def main():
    sample_function(config_dict)

if __name__ == "__main__":
    main()
